@@ -22,7 +22,7 @@
 
 import os.path
 
-from pyedb.generic.general_methods import ET, pyedb_function_handler
+from pyedb.generic.general_methods import ET
 from pyedb.ipc2581.bom.bom import Bom
 from pyedb.ipc2581.bom.bom_item import BomItem
 from pyedb.ipc2581.content.content import Content
@@ -48,7 +48,6 @@ class Ipc2581(object):
         self.design_name = ""
         self.top_bottom_layers = []
 
-    @pyedb_function_handler()
     def load_ipc_model(self):
         self.design_name = self._pedb.cell_names[0]
         self.content.step_ref = self.design_name
@@ -69,15 +68,19 @@ class Ipc2581(object):
         self.add_drills()
         self._pedb.logger.info("Parsing EDB Completed!")
 
-    @pyedb_function_handler()
     def add_pdstack_definition(self):
         for padstack_name, padstackdef in self._pedb.padstacks.definitions.items():
             padstack_def = PadstackDef()
             padstack_def.name = padstack_name
             padstack_def.padstack_hole_def.name = padstack_name
-            if padstackdef.hole_properties:
+            if not self._pedb.grpc:
+                if padstackdef.hole_properties:
+                    padstack_def.padstack_hole_def.diameter = self.from_meter_to_units(
+                        padstackdef.hole_properties[0], self.units
+                    )
+            else:
                 padstack_def.padstack_hole_def.diameter = self.from_meter_to_units(
-                    padstackdef.hole_properties[0], self.units
+                    padstackdef.hole_diameter, self.units
                 )
             for layer, pad in padstackdef.pad_by_layer.items():
                 if pad.parameters_values:
@@ -126,7 +129,7 @@ class Ipc2581(object):
                         primitive_ref = "Default"
                     padstack_def.add_padstack_pad_def(layer=layer, pad_use="REGULAR", primitive_ref=primitive_ref)
             for layer, antipad in padstackdef.antipad_by_layer.items():
-                if antipad.parameters_values:
+                if antipad:
                     if antipad.geometry_type == 1:
                         primitive_ref = "CIRCLE_{}".format(
                             self.from_meter_to_units(antipad.parameters_values[0], self.units)
@@ -171,7 +174,7 @@ class Ipc2581(object):
                         primitive_ref = "Default"
                     padstack_def.add_padstack_pad_def(layer=layer, pad_use="ANTIPAD", primitive_ref=primitive_ref)
             for layer, thermalpad in padstackdef.thermalpad_by_layer.items():
-                if thermalpad.parameters_values:
+                if thermalpad:
                     if thermalpad.geometry_type == 1:
                         primitive_ref = "CIRCLE_{}".format(
                             self.from_meter_to_units(thermalpad.parameters_values[0], self.units)
@@ -218,7 +221,6 @@ class Ipc2581(object):
             if not padstack_def.name in self.ecad.cad_data.cad_data_step.padstack_defs:
                 self.ecad.cad_data.cad_data_step.padstack_defs[padstack_def.name] = padstack_def
 
-    @pyedb_function_handler()
     def add_bom(self):
         # Bom
         for part_name, components in self._pedb.components.components_by_partname.items():
@@ -242,9 +244,11 @@ class Ipc2581(object):
                 )
             self.bom.bom_items.append(bom_item)
 
-    @pyedb_function_handler()
     def add_layers_info(self):
-        self.design_name = self._pedb.layout.cell.GetName()
+        if not self._pedb.grpc:
+            self.design_name = self._pedb.layout.cell.GetName()
+        else:
+            self.design_name = self._pedb.layout.cell.name
         self.ecad.design_name = self.design_name
         self.ecad.cad_header.units = self.units
         self.ecad.cad_data.stackup.total_thickness = self.from_meter_to_units(
@@ -254,7 +258,7 @@ class Ipc2581(object):
         self.layers_name = list(self._pedb.stackup.signal_layers.keys())
         self.top_bottom_layers = [self.layers_name[0], self.layers_name[-1]]
         sequence = 0
-        for layer_name in list(self._pedb.stackup.stackup_layers.keys()):
+        for layer_name in list(self._pedb.stackup.layers.keys()):
             sequence += 1
             self.content.add_layer_ref(layer_name)
             layer_color = self._pedb.stackup.layers[layer_name].color
@@ -268,31 +272,20 @@ class Ipc2581(object):
             loss_tg = 0
             embedded = "NOT_EMBEDDED"
             # try:
-            material_name = self._pedb.stackup.layers[layer_name]._edb_layer.GetMaterial()
-            edb_material = self._pedb.edb_api.definition.MaterialDef.FindByName(self._pedb.active_db, material_name)
+            material_name = self._pedb.stackup.layers[layer_name].material
+            material = self._pedb.materials[material_name]
             material_type = "CONDUCTOR"
             if self._pedb.stackup.layers[layer_name].type == "dielectric":
                 layer_type = "DIELPREG"
                 material_type = "DIELECTRIC"
-
-                permitivity = edb_material.GetProperty(self._pedb.edb_api.definition.MaterialPropertyId.Permittivity)[1]
-                if not isinstance(permitivity, float):
-                    permitivity = permitivity.ToDouble()
-                loss_tg = edb_material.GetProperty(
-                    self._pedb.edb_api.definition.MaterialPropertyId.DielectricLossTangent
-                )[1]
-                if not isinstance(loss_tg, float):
-                    loss_tg = loss_tg.ToDouble()
+                permitivity = material.permittivity
+                loss_tg = material.loss_tangent
                 conductivity = 0
             if layer_type == "CONDUCTOR":
-                conductivity = edb_material.GetProperty(self._pedb.edb_api.definition.MaterialPropertyId.Conductivity)[
-                    1
-                ]
-                if not isinstance(conductivity, float):
-                    conductivity = conductivity.ToDouble()
+                conductivity = material.conductivity
             self.ecad.cad_header.add_spec(
                 name=layer_name,
-                material=self._pedb.stackup.layers[layer_name]._edb_layer.GetMaterial(),
+                material=material_name,
                 layer_type=material_type,
                 conductivity=str(conductivity),
                 dielectric_constant=str(permitivity),
@@ -319,24 +312,24 @@ class Ipc2581(object):
         self.content.add_layer_ref("Drill")
         self.content.dict_colors.add_color("{}".format("Drill"), "255", "255", "255")
 
-    @pyedb_function_handler()
     def add_components(self):
-        for item in self._pedb.components.components.values():
+        for item in self._pedb.components.instances.values():
             self.ecad.cad_data.cad_data_step.add_component(item)
 
-    @pyedb_function_handler()
     def add_logical_nets(self):
         nets = [i for i in self._pedb.nets.nets.values()]
         for net in nets:
             self.ecad.cad_data.cad_data_step.add_logical_net(net)
 
-    @pyedb_function_handler()
     def add_profile(self):
-        profile = self._pedb.modeler.primitives_by_layer["Outline"]
-        for prim in profile:
-            self.ecad.cad_data.cad_data_step.add_profile(prim)
+        profile = self._pedb.modeler.primitives_by_layer.get("Outline")
+        if profile is None:
+            self._pedb.logger.warning("Layer 'Outline' not found.")
+        else:
+            profile = self._pedb.modeler.primitives_by_layer["Outline"]
+            for prim in profile:
+                self.ecad.cad_data.cad_data_step.add_profile(prim)
 
-    @pyedb_function_handler()
     def add_layer_features(self):
         layers = {i: j for i, j in self._pedb.stackup.layers.items()}
         padstack_instances = list(self._pedb.padstacks.instances.values())
@@ -346,7 +339,6 @@ class Ipc2581(object):
             self.ecad.cad_data.cad_data_step.add_layer_feature(layer, polys[layer_name])
         self.ecad.cad_data.cad_data_step.add_padstack_instances(padstack_instances, padstack_defs)
 
-    @pyedb_function_handler()
     def add_drills(self):
         via_list = [
             obj for obj in list(self._pedb.padstacks.instances.values()) if not obj.start_layer == obj.stop_layer
@@ -355,39 +347,38 @@ class Ipc2581(object):
 
         self.ecad.cad_data.cad_data_step.add_drill_layer_feature(via_list, "DRILL_1-{}".format(l1))
 
-    @pyedb_function_handler()
     def from_meter_to_units(self, value, units):
-        if isinstance(value, str):
-            value = float(value)
-        if isinstance(value, list):
-            returned_list = []
-            for val in value:
-                if isinstance(val, str):
-                    val = float(val)
-                if units.lower() == "mm":
-                    returned_list.append(round(val * 1000, 4))
-                if units.lower() == "um":
-                    returned_list.append(round(val * 1e6, 4))
+        if value:
+            if isinstance(value, str):
+                value = float(value)
+            if isinstance(value, list):
+                returned_list = []
+                for val in value:
+                    if isinstance(val, str):
+                        val = float(val)
+                    if units.lower() == "mm":
+                        returned_list.append(round(val * 1000, 4))
+                    if units.lower() == "um":
+                        returned_list.append(round(val * 1e6, 4))
+                    if units.lower() == "mils":
+                        returned_list.append(round(val * 39370.079, 4))
+                    if units.lower() == "inch":
+                        returned_list.append(round(val * 39.370079, 4))
+                    if units.lower() == "cm":
+                        returned_list.append(round(val * 100, 4))
+                return returned_list
+            else:
+                if units.lower() == "millimeter":
+                    return round(value * 1000, 4)
+                if units.lower() == "micrometer":
+                    return round(value * 1e6, 4)
                 if units.lower() == "mils":
-                    returned_list.append(round(val * 39370.079, 4))
+                    return round(value * 39370.079, 4)
                 if units.lower() == "inch":
-                    returned_list.append(round(val * 39.370079, 4))
-                if units.lower() == "cm":
-                    returned_list.append(round(val * 100, 4))
-            return returned_list
-        else:
-            if units.lower() == "millimeter":
-                return round(value * 1000, 4)
-            if units.lower() == "micrometer":
-                return round(value * 1e6, 4)
-            if units.lower() == "mils":
-                return round(value * 39370.079, 4)
-            if units.lower() == "inch":
-                return round(value * 39.370079, 4)
-            if units.lower() == "centimeter":
-                return round(value * 100, 4)
+                    return round(value * 39.370079, 4)
+                if units.lower() == "centimeter":
+                    return round(value * 100, 4)
 
-    @pyedb_function_handler()
     def write_xml(self):
         if self.file_path:
             ipc = ET.Element("IPC-2581")
